@@ -11,7 +11,7 @@ Date: 2022/6/16 5:33 下午
 from .configuration import configuration  # 连接用来读取配置文件
 from .encryption_and_decryption import EncDec #加解密
 from .mysql import mysql_class #mysql包
-from .translations.baidu_translate import *
-from .translations.google_translate import *
+# from .translations.baidu_translate import *
+# from .translations.google_translate import *
 from .nlp import nlp_tools
 from .es import EsOp #es
\ No newline at end of file
