@@ -11,7 +11,7 @@ Date: 2022/8/1 4:58 下午
 
 import pymysql
 import pandas as pd
-from configuration import  configuration
+from .configuration import  configuration
 from sqlalchemy import create_engine
 
 
